@@ -19,7 +19,7 @@ Readonly::Hash our %ENTITIES => (
 Readonly::Scalar our $ENTITIES => join q{}, keys %ENTITIES;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Decode chars.
 sub decode {
@@ -204,19 +204,16 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<App::SGML2PYX>,
-L<PYX::Checker>,
-L<PYX::Filter>,
-L<PYX::GraphViz>,
-L<PYX::Optimalization>,
 L<PYX>,
+L<PYX::GraphViz>,
+L<PYX::Hist>,
 L<PYX::Parser>,
-L<PYX::Sort>,
 L<PYX::Stack>,
-L<PYX::Write::Raw>,
-L<PYX::Write::Tags>,
-L<PYX::Write::Tags::Code>,
-L<PYX::XMLNorm>.
+L<Task::PYX>.
+
+=head1 REPOSITORY
+
+L<https://github.com/tupinek/PYX-Utils>
 
 =head1 AUTHOR
 
@@ -224,10 +221,11 @@ Michal Špaček L<skim@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2005-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
